@@ -14,11 +14,10 @@ GeomInteractiveTile <- ggproto(
   "GeomInteractiveTile",
   GeomTile,
   default_aes = add_default_interactive_aes(GeomTile),
-  draw_key = function(data, params, size) {
-    gr <- GeomTile$draw_key(data, params, size)
-    add_interactive_attrs(gr, data, data_attr = "key-id")
-  },
-  draw_panel = function(self, data, panel_params, coord, linejoin = "mitre") {
-    GeomInteractiveRect$draw_panel(data, panel_params, coord, linejoin = linejoin)
+  non_missing_aes = c("xmin", "xmax", "ymin", "ymax"),
+  parameters = interactive_geom_parameters,
+  draw_key = interactive_geom_draw_key,
+  draw_panel = function(self, data, panel_params, coord, ..., .ipar = IPAR_NAMES) {
+    GeomInteractiveRect$draw_panel(data, panel_params, coord, ..., .ipar = .ipar)
   }
 )
