@@ -18,7 +18,7 @@ if(!(is.data.frame(result) && nrow(result) > 0)){
   expect_true(is.character(result) && nzchar(result) > 0)
   expect_true(ggiraph::font_family_exists(result))
   result <- ggiraph:::default_fontname()
-  expect_true(is.list(result) && names(result) %in% c("sans", "serif", "mono", "symbol"))
+  expect_true(is.list(result) && all(names(result) %in% c("sans", "serif", "mono", "symbol")))
   result <- ggiraph:::validated_fonts()
-  expect_true(is.list(result) && names(result) %in% c("sans", "serif", "mono", "symbol"))
+  expect_true(is.list(result) && all(names(result) %in% c("sans", "serif", "mono", "symbol")))
 }
